hotspot/src/share/vm/gc/g1/g1CollectedHeap.cpp
changeset 37120 7f2e805b6b77
parent 37085 53ccf09a724f
child 37125 188d715655a3
--- a/hotspot/src/share/vm/gc/g1/g1CollectedHeap.cpp	Wed Mar 16 10:28:57 2016 +0100
+++ b/hotspot/src/share/vm/gc/g1/g1CollectedHeap.cpp	Wed Mar 16 13:38:54 2016 +0100
@@ -3222,10 +3222,13 @@
   _verifier->verify_region_sets_optional();
   _verifier->verify_dirty_young_regions();
 
-  // This call will decide whether this pause is an initial-mark
-  // pause. If it is, during_initial_mark_pause() will return true
-  // for the duration of this pause.
-  g1_policy()->decide_on_conc_mark_initiation();
+  // We should not be doing initial mark unless the conc mark thread is running
+  if (!_cmThread->should_terminate()) {
+    // This call will decide whether this pause is an initial-mark
+    // pause. If it is, during_initial_mark_pause() will return true
+    // for the duration of this pause.
+    g1_policy()->decide_on_conc_mark_initiation();
+  }
 
   // We do not allow initial-mark to be piggy-backed on a mixed GC.
   assert(!collector_state()->during_initial_mark_pause() ||